import os
import oss2
import json
import time
import uuid
import requests
from datetime import datetime
import hashlib
from meutils.pipe import *
from meutils.hash_utils import md5

BASE_URL = "https://hailuoai.video"
TOKEN = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM1NjI3ODcsInVzZXIiOnsiaWQiOiIzMDI4MzM4Njc3NzE5NDkwNTgiLCJuYW1lIjoibWUgYmV0dGVyIiwiYXZhdGFyIjoiaHR0cHM6Ly9saDMuZ29vZ2xldXNlcmNvbnRlbnQuY29tL2EvQUNnOG9jSWdTU0NoczFENHNUajFTVGs3UHNUbTd5NTNKRFg5OW84QnhwWmNWNjU2MEFKYlJnPXM5Ni1jIiwiZGV2aWNlSUQiOiIifX0.6RgLLZGa_zFYWW0e_thcfBWWrZIS8KuBkyd6AkNZSEE"
# TOKEN = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM0MDY1MzUsInVzZXIiOnsiaWQiOiIzMDI4MzM4Njc3NzE5NDkwNTgiLCJuYW1lIjoibWUgYmV0dGVyIiwiYXZhdGFyIjoiaHR0cHM6Ly9saDMuZ29vZ2xldXNlcmNvbnRlbnQuY29tL2EvQUNnOG9jSWdTU0NoczFENHNUajFTVGs3UHNUbTd5NTNKRFg5OW84QnhwWmNWNjU2MEFKYlJnPXM5Ni1jIiwiZGV2aWNlSUQiOiIifX0.mcozMacSciz0MORdleOMS_uhrixhIlpQmFmUwvn81I4"
# TOKEN = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM1MzMwNTAsInVzZXIiOnsiaWQiOiIzMDI4MzM4Njc3NzE5NDkwNTgiLCJuYW1lIjoibWUgYmV0dGVyIiwiYXZhdGFyIjoiaHR0cHM6Ly9saDMuZ29vZ2xldXNlcmNvbnRlbnQuY29tL2EvQUNnOG9jSWdTU0NoczFENHNUajFTVGs3UHNUbTd5NTNKRFg5OW84QnhwWmNWNjU2MEFKYlJnPXM5Ni1jIiwiZGV2aWNlSUQiOiIifX0.R1wHnd5LZ3uuvEqMV5nodHjzksrJ5RVaSaqjnt_dfDQ"
# BASE_URL = "https://hailuoai.com"
# TOKEN = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzMwMTkwMDcsInVzZXIiOnsiaWQiOiIyMjkwODQ3NTA2MDEzODgwMzciLCJuYW1lIjoi5bCP6J665bi9ODAzNyIsImF2YXRhciI6Imh0dHBzOi8vY2RuLnlpbmdzaGktYWkuY29tL3Byb2QvdXNlcl9hdmF0YXIvMTcwNjI2NzcxMTI4Mjc3MDg3Mi0xNzMxOTQ1NzA2Njg5NjU4OTZvdmVyc2l6ZS5wbmciLCJkZXZpY2VJRCI6IjI0MzcxMzI1MjU0NTk4NjU2MiIsImlzQW5vbnltb3VzIjpmYWxzZX19.dZwNcZfVnHHWYJRiv3wOrD2LSM3X9jzof6jxH2OcZOI"
# TOKEN="eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJleHAiOjE3MzM1MzI3NjUsInVzZXIiOnsiaWQiOiIyNDM3MTMyNTI3OTc2NDA3MDgiLCJuYW1lIjoi5bCP6J665bi9NzA4IiwiYXZhdGFyIjoiaHR0cHM6Ly9jZG4ueWluZ3NoaS1haS5jb20vcHJvZC91c2VyX2F2YXRhci8xNzA2MjY3MzY0MTY0NDA0MDc3LTE3MzE5NDU3MDY2ODk2NTg5Nm92ZXJzaXplLnBuZyIsImRldmljZUlEIjoiMjQzNzEzMjUyNTQ1OTg2NTYyIiwiaXNBbm9ueW1vdXMiOmZhbHNlfX0.7Twuu96zja8htvqY0Psm3bJV8sHAVIBke79JR-5YW4Y"
USER_ID = "3de88ad0-8a38-48a9-8ed3-0d63f9c71296"
DEVICE_ID = "302833759512764417"

headers = {
    "token": TOKEN,
    "content-type": "application/json",
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/127.0.0.0 Safari/537.36"
}


def calculate_md5(file_path):
    """计算文件的MD5哈希值"""
    hash_md5 = hashlib.md5()
    with open(file_path, "rb") as f:  # 打开文件，以二进制读取模式
        for chunk in iter(lambda: f.read(4096), b""):  # 读取文件的块
            hash_md5.update(chunk)  # 更新哈希值
    logger.debug(hash_md5.hexdigest()) # 5d850db413c9b55eff61d47cbec208e7
    return hash_md5.hexdigest()


def upload_path(image_path):
    tt = "{}000".format(int(time.time()))
    url = "https://hailuoai.video/v1/api/files/request_policy?device_platform=web&app_id=3001&version_code=22201&uuid={}&device_id={}&os_name=Windows&browser_name=chrome&device_memory=8&cpu_core_num=20&browser_language=zh-CN&browser_platform=Win32&screen_width=2560&screen_height=1440&unix={}".format(
        USER_ID, DEVICE_ID, tt)

    url = f"{BASE_URL}/v1/api/files/request_policy?device_platform=web&app_id=3001&version_code=22201&uuid={USER_ID}&device_id={DEVICE_ID}&os_name=Windows&browser_name=chrome&device_memory=8&cpu_core_num=20&browser_language=zh-CN&browser_platform=Win32&screen_width=2560&screen_height=1440&unix={tt}"
    res = requests.get(url, headers=headers)
    data = res.json()["data"]

    print(data)
    # 提供的认证信息
    access_key_id = data["accessKeyId"]
    access_key_secret = data["accessKeySecret"]
    security_token = data["securityToken"]
    bucket_name = data["bucketName"]
    endpoint = data["endpoint"]
    dir_name = data["dir"]

    # 创建OSS客户端
    auth = oss2.StsAuth(access_key_id, access_key_secret, security_token)
    bucket = oss2.Bucket(auth, endpoint, bucket_name)

    # 要上传的文件路径和文件名
    obj_name = "{}.{}".format(str(uuid.uuid4()), image_path.split(".")[-1])
    object_name = f"{dir_name}/{obj_name}"

    # 上传文件
    bucket.put_object_from_file(object_name, image_path)
    # bucket.put_object(object_name, Path(image_path).read_bytes())


    print(dir_name, obj_name)
    print("File uploaded successfully")
    origin_name = image_path.split("/")[-1]
    size = str(os.path.getsize(image_path))
    h_md5 = calculate_md5(image_path)
    mini_type = image_path.split(".")[-1]
    up_tt = "{}000".format(int(time.time()))
    up_url = "https://hailuoai.video/v1/api/files/policy_callback?device_platform=web&app_id=3001&version_code=22201&uuid={}&device_id={}&os_name=Windows&browser_name=chrome&device_memory=8&cpu_core_num=20&browser_language=zh-CN&browser_platform=Win32&screen_width=2560&screen_height=1440&unix={}".format(
        USER_ID, DEVICE_ID, up_tt)

    print(up_url)

    up_url = f"{BASE_URL}/v1/api/files/policy_callback?device_platform=web&app_id=3001&version_code=22201&uuid={USER_ID}&device_id={DEVICE_ID}&os_name=Windows&browser_name=chrome&device_memory=8&cpu_core_num=20&browser_language=zh-CN&browser_platform=Win32&screen_width=2560&screen_height=1440&unix={up_tt}"

    payload = json.dumps({
        "fileName": obj_name,
        "originFileName": origin_name,
        "dir": dir_name,
        "endpoint": endpoint,
        "bucketName": bucket_name,
        "size": size,
        "mimeType": mini_type,
        "fileMd5": h_md5
    })

    # {
    #     "fileName": "db884a7c-99a4-40f5-929e-db8769dbf64a.png",
    #     "originFileName": "503af3b5-9c3b-4bdc-a6d4-256debce3dd5_00001_.png",
    #     "dir": "cdn-yingshi-ai-com/prod/2024-10-28-09/user/multi_chat_file",
    #     "endpoint": "oss-cn-wulanchabu.aliyuncs.com",
    #     "bucketName": "minimax-public-cdn",
    #     "size": "1681865",
    #     "mimeType": "png",
    #     "fileMd5": "923e10167a2d7b36e866319dad738b1e",
    #     "fileScene": 10
    # }

    res = requests.post(up_url, data=payload, headers=headers)
    print(res.text)
    print(payload)
    print(res.json())


upload_path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/data/cowboy-hat-face.webp")


# print(md5(Path("/Users/betterme/PycharmProjects/AI/MeUtils/meutils/data/cowboy-hat-face.webp").read_bytes()))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : redis_cache
# @Time         : 2024/12/6 10:46
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :  https://hermescache.readthedocs.io/en/latest/
# https://mp.weixin.qq.com/s/-T2UmkinmtQoNQo4DVpnfw


import hermes.backend.redis
import hermes.backend.inprocess

from meutils.db.redis_db import pool

cache = hermes.Hermes(
    backend=hermes.backend.redis.Backend,
    connection_pool=pool
)

cache_inmemory = hermes.Hermes(
    backend=hermes.backend.inprocess.Backend,
)

acache_inmemory = hermes.Hermes(
    backend=hermes.backend.inprocess.AsyncBackend,
)




if __name__ == '__main__':
    from meutils.pipe import *

    @cache(tags=('test',))
    async def foo(a, b):
        time.sleep(3)
        logger.debug('没有缓存')

        return a * b


    # @cache(tags=('test',), key=lambda fn, a, b: f'avg:{a}')  # 这样可以忽略b
    # async def func_ignore(a, b):
    #     await asyncio.sleep(5)
    #     logger.debug('异步函数')
    #     return a, b


    # arun(func_ignore(1, 1))
    # ttl: Optional[int] = None,
    # tags: Sequence[str] = (),
    # key: Optional[Callable] = None,
    # @cache(ttl=100, key=lambda fn, a, b: (a, b))
    # def func(x, y):
    #     logger.debug('xxxxxxx')
    #     return x

    arun(foo(1, 2))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : result
# @Time         : 2021/2/18 6:16 下午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *
from meutils.zk_utils import zk_cfg
from meutils.request_utils import request


def get_ac(docid, parser=lambda x: x.get('item', {})):
    return request(f"{zk_cfg.ac_url}/{docid}", parser=parser)


def get_acs(docids, max_workers=10, parser=lambda x: x.get('item', {}).get('title')):
    func = functools.partial(get_ac, parser=parser)
    return docids | xThreadPoolExecutor(func, max_workers) | xlist


def get_simbert_vectors(sentences, url=None, json=None):
    """适合小批量请求
    :param sentences:
    :return:

        vectors_list = sentences_list | xThreadPoolExecutor(request_func, max_workers)
        np.row_stack(vectors_list)
    """
    if url is None:
        url = 'http://10.210.10.94:32651/simbert' if is_open() else 'http://10.211.10.33:32520/simbert'
    if json is None:
        json = {'sentences': sentences}

    data = request(url, json).get('vectors')

    return np.array(data, 'float32')


if __name__ == '__main__':
    print(get_acs(['fengxing_144094389']))

    # print(get_simbert_vectors('bert向量化', is_lite='1').shape)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : tql-Python.
# @File         : coordinate
# @Time         : 2019-09-22 16:00
# @Author       : yuanjie
# @Email        : yuanjie@xiaomi.com
# @Software     : PyCharm
# @Description  : 

import re
import requests

url = 'https://blog.csdn.net/Yellow_python/article/details/81115987'
header = {'User-Agent': 'Opera/8.0 (Windows NT 5.1; U; en)'}
r = requests.get(url, headers=header)
contain = re.findall('<pre><code>([\s\S]+?)</code></pre>', r.text)[0].strip()
with open('coordinate.txt', 'w', encoding='utf-8') as f:
    f.write(contain)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/11/5 18:01
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo https://docs.aimlapi.com/api-references/video-models/minimax/hailuo-02

# todo hailuo2.0 首尾帧

from meutils.pipe import *
from openai import AsyncOpenAI
from meutils.schemas.video_types import SoraVideoRequest, Video
from meutils.io.files_utils import to_base64, to_url_fal
from meutils.io.image import image_resize

"""
model
undefined · enum
Possible values: alibaba/wan2.5-i2v-preview
prompt
string · min: 1 · max: 800
The text description of the scene, subject, or action to generate in the video.

image_url
string · uri
A direct link to an online image or a Base64-encoded local image that will serve as the visual base or the first frame for the video.

resolution
string · enum
An enumeration where the short side of the video frame determines the resolution.

Default: 720p
Possible values: 480p720p1080p
duration
integer · enum
The length of the output video in seconds.

Possible values: 510
negative_prompt
string
The description of elements to avoid in the generated video.

enable_prompt_expansion
boolean
Whether to enable prompt expansion.

Default: true
seed
integer
Varying the seed integer is a way to get different results for the same other request parameters. Using the same value for an identical request will produce similar results. If unspecified, a random number is chosen.
"""


class Tasks(object):

    def __init__(self, base_url: Optional[str] = None, api_key: str = None):
        base_url = "https://api.aimlapi.com/v2"
        self.client = AsyncOpenAI(base_url=base_url, api_key=api_key)

    async def create(self, request: SoraVideoRequest):
        payload = {
            "model": request.model,
            "prompt": request.prompt,

            **(request.metadata or {})
        }

        if request.seconds:
            payload["duration"] = int(request.seconds)

        if request.resolution:
            payload['resolution'] = request.resolution

        if request.ratio:
            payload["aspect_ratio"] = request.ratio

        if request.generate_audio is not None:
            payload["generate_audio_switch"] = request.generate_audio

        if request.style is not None:
            payload["style"] = request.style

        if image_urls := request.input_reference:
            if any(i in request.model for i in {'sora', }):
                logger.debug(bjson(payload))

                if 'sora' in request.model:
                    w, h = map(int, request.size.split('x'))
                    payload["aspect_ratio"] = "16:9" if w > h else "9:16"

                image_urls[0] = await image_resize(image_urls[0], request.size, "url")

                logger.debug(image_urls)

            elif 'luma' in request.model:
                payload["keyframes"] = {
                    f"frame{i}": {
                        "type": "image",
                        "url": url
                    }

                    for i, url in enumerate(image_urls)}

            elif 'runway' in request.model:
                payload["references"] = [
                    {
                        "type": "image",
                        "url": url
                    }

                    for i, url in enumerate(image_urls)
                ]

            payload['model'] = request.model.replace("text-to-video", "image-to-video").replace("t2v", "i2v")

            # if len(image_urls) > 1:
            #     payload["image_list"] = image_urls
            # else:
            #     payload["image_url"] = image_urls[0]

            payload["image_url"] = image_urls[0]
            payload["image_list"] = image_urls

            # https://aimlapi.com/models/veo-3-1-reference-to-video
            # 模型区分 参考图 首尾帧
            # if any( i in request.model for i in {"veo"}):

            # klingai/video-o1-reference-to-video image_list
            # klingai/video-o1-image-to-video image_url last_image_url

        else:
            payload['model'] = request.model.replace("image-to-video", "text-to-video").replace("i2v", "t2v")

        # 首尾帧
        if request.first_frame_image:
            if request.model.startswith(("klingai/video-o1",)):
                payload['model'] = "klingai/video-o1-image-to-video"

            payload["image_url"] = request.first_frame_image
            payload["first_frame_image"] = request.first_frame_image

        if request.last_frame_image:
            payload["last_image_url"] = request.last_frame_image

        # 数字人 对口型
        if request.audio and any(i in request.model for i in {"omnihuman", 'avatar'}):
            payload['image_url'] = request.image
            payload['audio_url'] = request.audio

        if request.video:
            if request.model.startswith(("alibaba/wan-2-6",)):
                payload["video_urls"] = [request.video]
                payload['model'] = "alibaba/wan-2-6-r2v"

            elif request.model.startswith(("runway",)):
                payload['frame_size'] = (request.size or "1280:720").replace('x', ':')
                payload["video_url"] = request.video


            else:
                payload["video_url"] = request.video
                payload['keep_audio'] = True

                if request.model.endswith('edit'):  # kling
                    payload['model'] = "klingai/video-o1-video-to-video-edit"
                else:
                    payload['model'] = "klingai/video-o1-video-to-video-reference"

        logany(bjson(payload))

        response = await self.client.post(
            path="/video/generations",
            body=payload,
            cast_to=object
        )
        """
        {
    "id": "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview",
    "status": "queued",
    "meta": {
        "usage": {
            "tokens_used": 105000
        }
    }
    
    {
    "generation_id": "339995387916622:minimax/hailuo-02",
    "status": "queued",
    "meta": {
        "usage": {
            "tokens_used": 588000
        }
    }
}
}
        """

        logger.debug(bjson(response))

        return response

    async def get(self, task_id: str):
        logger.debug(task_id)

        response = await self.client.get(
            path=f"/video/generations?generation_id={task_id}",
            cast_to=object
        )
        """
        {
    "id": "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview",
    "status": "completed",
    "video": {
        "url": "https://cdn.aimlapi.com/alpaca/1d/dd/20251107/30b07d9c/42740107-9913239d-4fa8-47ea-b51d-d313e29caba5.mp4?Expires=1762593280&OSSAccessKeyId=LTAI5tBLUzt9WaK89DU8aECd&Signature=Guk6apyEnKeuniLv0mcBJhkHO%2FI%3D"
    }
}

{
    "id": "",
    "status": "unknown",
    "error": {
        "name": "Error",
        "message": "invalid params, task_id cannot by empty"
    }
}

        """
        logger.debug(bjson(response))

        status = response
        if response.get('error'):
            status = 'failed'

        video = Video(
            id=task_id,
            status=status,
            video_url=(response.get("video") or {}).get("url"),

            error=response.get("error")
        )

        # logger.debug(bjson(video))

        return video


if __name__ == "__main__":
    api_key = "603051fc1d7e49e19de2c67521d4a30e"
    # a63443199c3e42ea90003e0261ccb246
    api_key = "a63443199c3e42ea90003e0261ccb246"

    model = "alibaba/wan2.5-i2v-preview"
    model = "minimax/hailuo-02"
    # model = "minimax/hailuo-02_1080P"
    # model = "minimax/hailuo-2.3-fast"
    # model = "minimax/hailuo-2.3-fast_768P"

    # model = "alibaba/wan2.5-i2v-preview_480p"

    # model = "kling-video-o1"
    # model = "kling-video-o1-video-to-video-edit" => "klingai/video-o1-video-to-video-edit"

    # model = "klingai/video-o1-reference-to-video"

    #         "model": "klingai/video-o1-video-to-video-reference",
    #         "model": "klingai/video-o1-video-to-video-edit",

    # model = "alibaba/wan-2-6-t2v_720p"

    # model = "openai/sora-2-pro-i2v"
    # model = "openai/sora-2-i2v"

    # 数字人
    # model = "klingai/avatar-standard"
    # model = "klingai/avatar-pro"
    # model = "bytedance/omnihuman/v1.5"

    # luma
    # model = "luma/ray-2"
    # model = "luma/ray-flash-2"
    #
    # # runway
    # model = "runway/gen4_turbo"
    # model = "runway/gen4_aleph"
    #
    # model = "pixverse/v5-5-image-to-video"

    # todo klingai/video-v2-6-pro-motion-control

    data = {
        "model": model,
        "prompt": '''Mona Lisa nervously puts on glasses with her hands and asks her off-screen friend to the left: ‘Do they suit me?’ She then tilts her head slightly to one side and then the other, so the unseen friend can better judge.''',
        "input_reference": "https://s2-111386.kwimgs.com/bs2/mmu-aiplatform-temp/kling/20240620/1.jpeg",
        # "resolution": "480p",
        "seconds": "4",
    }

    data = {
        "model": model,
        "prompt": '''Mona Lisa nervously puts on glasses with her hands and asks her off-screen friend to the left: ‘Do they suit me?’ She then tilts her head slightly to one side and then the other, so the unseen friend can better judge.''',
        "input_reference": "https://ark-project.tos-cn-beijing.volces.com/doc_image/seepro_first_frame.jpeg,https://ark-project.tos-cn-beijing.volces.com/doc_image/seepro_last_frame.jpeg",
        # "resolution": "480p",
        "seconds": "5",
    }

    data = {
        "model": model,
        "prompt": "A graceful ballerina dancing outside a circus tent on green grass, with colorful wildflowers swaying around her as she twirls and poses in the meadow.",
        # "input_reference": [
        #     "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-1.png",
        #     "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-2.png",
        #     # "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-3.png"
        # ],
        "first_frame_image": "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-1.png",
        "last_frame_image": "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-2.png",

        # "video": "https://zovi0.github.io/public_misc/kling-v2-master-t2v-racoon.mp4",

        # "size": "1792x1024",
        # "size": "720x1280",
        # "size": "1280x720",

        # "size": "16:9",

        "seconds": "6",
        # "resolution": "720p"
    }

    data = {"prompt": "飞起来", "model": model,
            "size": "1920x1080",
            "seconds": "6",
            "first_frame_image": "https://111-1318855541.cos.ap-guangzhou.myqcloud.com/mirrorsea-flow/20260125/f2e1ee1e302e4bc5a0d813e72a2de1f6.jpg",
            "last_frame_image": "https://111-1318855541.cos.ap-guangzhou.myqcloud.com/mirrorsea-flow/20260125/b148adc981ba4bb9b85b6e2e1801c730.jpg"}
    # data = {
    #     "model": model,
    #     "prompt": "A graceful ballerina dancing outside a circus tent on green grass, with colorful wildflowers swaying around her as she twirls and poses in the meadow.",
    #     # "input_reference": [
    #     #     "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-1.png",
    #     #     "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-2.png",
    #     #     # "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-3.png"
    #     # ],
    #
    #     "first_frame_image": "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-1.png",
    #     "last_frame_image": "https://storage.googleapis.com/falserverless/example_inputs/veo31-r2v-input-2.png",
    #
    #     # "size": "1792x1024",
    #     # "size": "720x1280",
    #     # "size": "1280x720",
    #
    #     # "size": "16:9",
    #
    #     "seconds": "5",
    #     # "resolution": "720p"
    # }
    # data = {
    #     "model": model,
    #     "prompt": "A powerful, matte black jeep, its robust frame contrasting with the lush green surroundings, navigates a winding jungle road, kicking up small clouds of dust and loose earth from its tires.",
    #     "video": "https://storage.googleapis.com/falserverless/example_inputs/krea_wan_14b_v2v_input.mp4"
    # }

    # {
    #     "model": "klingai/video-o1-image-to-video",
    #     "prompt": "A jellyfish in the ocean",
    #     "image_url": "https://upload.wikimedia.org/wikipedia/commons/3/35/Maldivesfish2.jpg",
    # }
    # {
    #     "model": "klingai/video-o1-video-to-video-edit",
    #     "prompt": "A powerful, matte black jeep, its robust frame contrasting with the lush green surroundings, navigates a winding jungle road, kicking up small clouds of dust and loose earth from its tires.",
    #     "video_url": "https://storage.googleapis.com/falserverless/example_inputs/krea_wan_14b_v2v_input.mp4"
    # }
    #

    # }

    # {
    #     "model": "klingai/video-v2-6-pro-image-to-video",
    #     "prompt": "A jellyfish in the ocean",
    #     "image_url": "https://upload.wikimedia.org/wikipedia/commons/3/35/Maldivesfish2.jpg",
    # }
    #
    #
    # data = {
    #     "model": "klingai/video-v2-6-pro-text-to-video",
    #     "prompt": "A DJ on the stand is playing, around a World War II battlefield, lots of explosions, thousands of dancing soldiers, between tanks shooting, barbed wire fences, lots of smoke and fire, black and white old video: hyper realistic, photorealistic, photography, super detailed, very sharp, on a very white background"
    # }

    # data = {
    #     "model": model,
    #     "image": "https://s2-111386.kwimgs.com/bs2/mmu-aiplatform-temp/kling/20240620/1.jpeg",
    #     "audio": "https://storage.googleapis.com/falserverless/example_inputs/omnihuman_audio.mp3"
    # }

    request = SoraVideoRequest(**data)

    logger.debug(bjson(request))

    tasks = Tasks(api_key=api_key)
    # arun(tasks.create(request))

    # 8ScCA7OzgWOHmwol1YMtJ

    # task_id = "9913239d-4fa8-47ea-b51d-d313e29caba5:alibaba/wan2.5-i2v-preview"
    # task_id = "nltmquwNYRj6xNz-0PSaC"
    task_id = "AaNgOpmRIehrLgl1kjYVG"
    arun(tasks.get(task_id))
